@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::App::Command::dumpphases;
 
-our $VERSION = '1.000006';
+our $VERSION = '1.000007';
 
 # ABSTRACT: Dump a textual representation of each phase's parts.
 
@@ -179,7 +179,7 @@ Dist::Zilla::App::Command::dumpphases - Dump a textual representation of each ph
 
 =head1 VERSION
 
-version 1.000006
+version 1.000007
 
 =head1 SYNOPSIS
 
@@ -191,7 +191,7 @@ version 1.000006
 
 If you are using an HTML-enabled POD viewer, you should see a screenshot of this in action:
 
-( Everyone else can visit L<http://kentnl.github.io/Dist-Zilla-App-Command-dumpphases/media/example_01.png> )
+( Everyone else can visit L<http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpphases/example_01.png> )
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -205,7 +205,7 @@ If you are using an HTML-enabled POD viewer, you should see a screenshot of this
 =end MetaPOD::JSON
 
 =for html <center>
-  <img src="http://kentnl.github.io/Dist-Zilla-App-Command-dumpphases/media/example_01.png"
+  <img src="http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpphases/example_01.png"
        alt="Screenshot"
        width="721"
        height="1007" />
