@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::dumpphases::Theme::basic::green;
 
-our $VERSION = '1.000006';
+our $VERSION = '1.000007';
 
 # ABSTRACT: A green color theme for dzil dumpphases
 
@@ -37,14 +37,6 @@ with 'Dist::Zilla::dumpphases::Role::Theme::SimpleColor';
 
 sub color { return 'green' }
 
-
-
-
-
-
-
-
-
 1;
 
 __END__
@@ -59,7 +51,7 @@ Dist::Zilla::dumpphases::Theme::basic::green - A green color theme for dzil dump
 
 =head1 VERSION
 
-version 1.000006
+version 1.000007
 
 =head1 SYNOPSIS
 
@@ -77,7 +69,11 @@ version 1.000006
 
 =end MetaPOD::JSON
 
-=for html <center><img src="http://kentnl.github.io/Dist-Zilla-App-Command-dumpphases/media/theme_basic_green.png" alt="Screenshot" width="715" height="372"/></center>
+=for html <center>
+  <img src="http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpphases/theme_basic_green.png"
+       alt="Screenshot"
+       width="715" height="372"/>
+</center>
 
 =head1 METHODS
 
